==> openjdk-24_24~29ea.orig.tar.xz: openjdk-24-24~29ea/test/langtools/jdk/javadoc/doclet/testPackageSummary/TestPackageSummary.java <==
/*
 * Copyright (c) 2017, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */


/*
 * @test
 * @bug 8189841 8253117 8263507 8320458
 * @summary Error in alternate row coloring in package-summary files
 * @summary Improve structure of package summary pages
 * @library  ../../lib/
 * @modules jdk.javadoc/jdk.javadoc.internal.tool
 * @build    javadoc.tester.* TestPackageSummary
 * @run main TestPackageSummary
 */

import javadoc.tester.JavadocTester;

public class TestPackageSummary extends JavadocTester {

    public static void main(String... args) throws Exception {
        var tester = new TestPackageSummary();
        tester.runTests();
    }

    @Test
    public void testSummaryLinks() {
        javadoc("-d", "out-links",
                "-sourcepath", testSrc,
                "-subpackages", "pkg:pkg1");
        checkExit(Exit.OK);

        checkOutput("pkg/package-summary.html", true,
                """
                    <ol class="toc-list">
                    <li><a href="#" tabindex="0">Description</a></li>
                    <li><a href="#class-summary" tabindex="0">Classes and Interfaces</a></li>
                    </ol>
                    """);
        checkOutput("pkg1/package-summary.html", true,
                """
                    <ol class="toc-list">
                    <li><a href="#" tabindex="0">Description</a></li>
                    <li><a href="#related-package-summary" tabindex="0">Related Packages</a></li>
                    <li><a href="#class-summary" tabindex="0">Classes and Interfaces</a></li>
                    </ol>
                    """);
        checkOutput("pkg1/sub/package-summary.html", true,
                """
                    <ol class="toc-list">
                    <li><a href="#" tabindex="0">Description</a></li>
                    <li><a href="#related-package-summary" tabindex="0">Related Packages</a></li>
                    <li><a href="#class-summary" tabindex="0">Classes and Interfaces</a></li>
                    </ol>
                    """);
    }

    @Test
    public void testStripes() {
        javadoc("-d", "out-stripes",
                "-sourcepath", testSrc,
                "pkg");
        checkExit(Exit.OK);

        checkOutput("pkg/package-summary.html", true,
                """
                    <div class="col-first even-row-color class-summary class-summary-tab2"><a href="C0.html" title="class in pkg">C0</a></div>
                    <div class="col-last even-row-color class-summary class-summary-tab2">&nbsp;</div>
                    <div class="col-first odd-row-color class-summary class-summary-tab2"><a href="C1.html" title="class in pkg">C1</a></div>
                    <div class="col-last odd-row-color class-summary class-summary-tab2">&nbsp;</div>
                    <div class="col-first even-row-color class-summary class-summary-tab2"><a href="C2.html" title="class in pkg">C2</a></div>
                    <div class="col-last even-row-color class-summary class-summary-tab2">&nbsp;</div>
                    <div class="col-first odd-row-color class-summary class-summary-tab2"><a href="C3.html" title="class in pkg">C3</a></div>
                    <div class="col-last odd-row-color class-summary class-summary-tab2">&nbsp;</div>
                    <div class="col-first even-row-color class-summary class-summary-tab2"><a href="C4.html" title="class in pkg">C4</a></div>
                    <div class="col-last even-row-color class-summary class-summary-tab2">&nbsp;</div>
                    """
        );
    }
}

==> openjdk-25_25~16ea.orig.tar.xz: openjdk-25-25~16ea/test/langtools/jdk/javadoc/doclet/testPackageSummary/TestPackageSummary.java <==
/*
 * Copyright (c) 2017, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */


/*
 * @test
 * @bug 8189841 8253117 8263507 8320458 8350638
 * @summary Error in alternate row coloring in package-summary files
 * @summary Improve structure of package summary pages
 * @library  ../../lib/
 * @modules jdk.javadoc/jdk.javadoc.internal.tool
 * @build    javadoc.tester.* TestPackageSummary
 * @run main TestPackageSummary
 */

import javadoc.tester.JavadocTester;

public class TestPackageSummary extends JavadocTester {

    public static void main(String... args) throws Exception {
        var tester = new TestPackageSummary();
        tester.runTests();
    }

    @Test
    public void testSummaryLinks() {
        javadoc("-d", "out-links",
                "-sourcepath", testSrc,
                "-subpackages", "pkg:pkg1");
        checkExit(Exit.OK);

        checkOutput("pkg/package-summary.html", true,
                """
                    <ol class="toc-list" tabindex="-1">
                    <li><a href="#" tabindex="0">Description</a></li>
                    <li><a href="#class-summary" tabindex="0">Classes and Interfaces</a></li>
                    </ol>
                    """);
        checkOutput("pkg1/package-summary.html", true,
                """
                    <ol class="toc-list" tabindex="-1">
                    <li><a href="#" tabindex="0">Description</a></li>
                    <li><a href="#related-package-summary" tabindex="0">Related Packages</a></li>
                    <li><a href="#class-summary" tabindex="0">Classes and Interfaces</a></li>
                    </ol>
                    """);
        checkOutput("pkg1/sub/package-summary.html", true,
                """
                    <ol class="toc-list" tabindex="-1">
                    <li><a href="#" tabindex="0">Description</a></li>
                    <li><a href="#related-package-summary" tabindex="0">Related Packages</a></li>
                    <li><a href="#class-summary" tabindex="0">Classes and Interfaces</a></li>
                    </ol>
                    """);
    }

    @Test
    public void testStripes() {
        javadoc("-d", "out-stripes",
                "-sourcepath", testSrc,
                "pkg");
        checkExit(Exit.OK);

        checkOutput("pkg/package-summary.html", true,
                """
                    <div class="col-first even-row-color class-summary class-summary-tab2"><a href="C0.html" title="class in pkg">C0</a></div>
                    <div class="col-last even-row-color class-summary class-summary-tab2">&nbsp;</div>
                    <div class="col-first odd-row-color class-summary class-summary-tab2"><a href="C1.html" title="class in pkg">C1</a></div>
                    <div class="col-last odd-row-color class-summary class-summary-tab2">&nbsp;</div>
                    <div class="col-first even-row-color class-summary class-summary-tab2"><a href="C2.html" title="class in pkg">C2</a></div>
                    <div class="col-last even-row-color class-summary class-summary-tab2">&nbsp;</div>
                    <div class="col-first odd-row-color class-summary class-summary-tab2"><a href="C3.html" title="class in pkg">C3</a></div>
                    <div class="col-last odd-row-color class-summary class-summary-tab2">&nbsp;</div>
                    <div class="col-first even-row-color class-summary class-summary-tab2"><a href="C4.html" title="class in pkg">C4</a></div>
                    <div class="col-last even-row-color class-summary class-summary-tab2">&nbsp;</div>
                    """
        );
    }
}
